@@ -540,16 +540,25 @@ def list_inheritable(p=0):
         return returned_dict
 
 
-def methods_inherited(base_class, p=0):
+def methods_inherited(base_class, p=0, table=0):
+    import pandas as pd
     class Base:
         pass
+
     class A(base_class):
         pass
-    returned_set = set(dir(A)) - set(dir(Base))
+
+    df = pd.DataFrame()
+    returned_set = tuple(set(dir(A)) - set(dir(Base)))
+    df['returned_set'] = returned_set
     try:
         abstract_methods = A.__abstractmethods__
+        df['__abstractmethods__'] = df['returned_set'].isin(abstract_methods)
+        df = df.sort_values(by=['__abstractmethods__'], ascending=False)
     except:
         abstract_methods = None
+    if table == 1:
+        return df
     if p == 1:
         from pprint import pprint
         pprint(returned_set, compact=True, width=120)
@@ -559,4 +568,4 @@ def methods_inherited(base_class, p=0):
         if abstract_methods:
             return returned_set, {'__abstractmethods__': abstract_methods}
         else:
-            return returned_set
\ No newline at end of file
+            return returned_set
